"""
desc.
"""

from . shroodinger__equation import *